@@ -125,13 +125,17 @@ class Amplitude:
             event_options (amplitude.event.EventOptions): Provide additional information for event
                 like user_id.
         """
-        identify_obj = Identify()
-        identify_obj.set(group_type, group_name)
-        self.identify(identify_obj, event_options)
+        event = IdentifyEvent(groups={group_type: group_name})
+        event.load_event_options(event_options)
+        self.track(event)
 
     def flush(self):
-        """Flush all event waiting to be sent in the buffer"""
-        self.__timeline.flush()
+        """Flush all event waiting to be sent in the buffer
+
+        Returns:
+            A list of Future objects for all destination plugins
+        """
+        return self.__timeline.flush()
 
     def add(self, plugin: Plugin):
         """Add the plugin object to client instance. Events tracked by this client instance will be
